@@ -1,10 +1,9 @@
 package strftime
 
 import (
+	"errors"
 	"fmt"
 	"sync"
-
-	"github.com/lestrrat-go/strftime/internal/errors"
 )
 
 // because there is no such thing was a sync.RWLocker
@@ -124,7 +123,7 @@ func (ds *specificationSet) Lookup(b byte) (Appender, error) {
 	}
 	v, ok := ds.store[b]
 	if !ok {
-		return nil, errors.Errorf(`lookup failed: '%%%c' was not found in specification set`, b)
+		return nil, fmt.Errorf(`lookup failed: '%%%c' was not found in specification set`, b)
 	}
 	return v, nil
 }
